get_cache_dir

Function get_cache_dir 

pub fn get_cache_dir() -> PathBuf
Get path to cache directory

This function will return the path to the $HOME/.cache directory, or to /tmp/mineflake if $HOME is not set. On Windows, this function will return the path to the %LOCALAPPDATA% directory, or to %TEMP% if %LOCALAPPDATA% is not set.